@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco++/fmc_all_cls.cc,v 1.40 2010/12/21 20:12:07 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco++/fmc_all_cls.cc,v 1.43 2012/02/13 17:43:06 hmb Exp $ */
 
 /* Purpose: netCDF arithmetic processor class methods: families of functions/methods */
 
-/* Copyright (C) 1995--2011 Charlie Zender
+/* Copyright (C) 1995--2012 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -1050,7 +1050,6 @@
     if(fmc_vtr.empty()){
       fmc_vtr.push_back( fmc_cls("mask",this,(int)PMASK1));
       fmc_vtr.push_back( fmc_cls("mask_clip",this,(int)PMASK_CLIP));
-
     }
   }
 
@@ -1068,7 +1067,6 @@
     std::vector<RefAST> vtr_args; 
     NcapVector<dmn_sct*> dmn_vtr;
 
-
     if(expr)
       vtr_args.push_back(expr);
 
@@ -1080,22 +1078,15 @@
       
     nbr_args=vtr_args.size();  
 
-
-   
-
     if(nbr_args<2)
       err_prn(sfnm, "Function has been called with less than two arguments"); 
 
-
     if(nbr_args >2 && !prs_arg->ntl_scn) 
       wrn_prn(sfnm," Function has been called with more than two arguments"); 
     
- 
     var=walker.out(vtr_args[0]);
     var_msk=walker.out(vtr_args[1]);
 
-
-
     // Deal with initial scan
     if(prs_arg->ntl_scn) {
 
@@ -1137,7 +1128,6 @@
        slb_sz=nco_typ_lng(var->type);    
        cnt=var->sz/var_msk->sz;
 
-
        (void)cast_void_nctype(NC_SHORT,&var_msk->val);
        //Dereference 
        sp=var_msk->val.sp; 
@@ -1155,10 +1145,8 @@
 	 }   
        } 
 
-
        (void)cast_nctype_void(NC_SHORT,&var_msk->val);
        var_msk=nco_var_free(var_msk);
-    
 
        return var;
       } 
@@ -1192,7 +1180,6 @@
       
       for(idx=0 ; idx<msk_sz ;idx++){
         // index out of bounds bomb out
-
         if(prs_arg->FORTRAN_IDX_CNV) {
 
           if( ip[idx]<1L || ip[idx] > var_sz){
@@ -1207,7 +1194,6 @@
             std::ostringstream os;
             os<<"Function reporting that index "<<ip[idx]<<" into "<<var->nm<<" is out of bounds 0"<<"-"<<var_sz-1; 
             err_prn(sfnm,os.str());         
-
           }
         }
 
@@ -1781,6 +1767,8 @@ var_sct * srt_cls::mst_fnd(bool &is_mtd, std::vector<RefAST> &args_vtr, fmc_cls
 
   RefAST tr;
   std::vector<RefAST> args_vtr; 
+  std::vector<std::string> cst_vtr;              
+
   // de-reference 
   prs_cls *prs_arg=walker.prs_arg;            
   vtl_typ lcl_typ;
@@ -1799,7 +1787,7 @@ var_sct * srt_cls::mst_fnd(bool &is_mtd, std::vector<RefAST> &args_vtr, fmc_cls
       
   nbr_args=args_vtr.size();  
 
-  susg="usage: var_out="+sfnm+"(start_exp,inc_exp,$dim)"; 
+  susg="usage: var_out="+sfnm+"(start_exp,inc_exp,$dim|var)"; 
 
   
   if(nbr_args<3)
@@ -1825,12 +1813,12 @@ var_sct * srt_cls::mst_fnd(bool &is_mtd, std::vector<RefAST> &args_vtr, fmc_cls
           
 
   /* third argument must be a single dimension */
-  if(args_vtr[2]->getType() != DIM_ID ) 
-    err_prn(sfnm,"Third argument must be a dimension\n"+susg); 
+  //if(args_vtr[2]->getType() != DIM_ID ) 
+  //  err_prn(sfnm,"Third argument must be a dimension\n"+susg); 
 
   // cast a var from using the dim arg
+  if(args_vtr[2]->getType() == DIM_ID ) 
   {
-   std::vector<std::string> cst_vtr;              
    cst_vtr.push_back(args_vtr[2]->getText());
      
    var_ret=ncap_cst_mk(cst_vtr,prs_arg);
@@ -1838,6 +1826,17 @@ var_sct * srt_cls::mst_fnd(bool &is_mtd, std::vector<RefAST> &args_vtr, fmc_cls
    // convert to type of first arg
    var_ret=nco_var_cnf_typ(var1->type,var_ret);  
 
+  }else{
+    // assume third argument is var - interested in only using its shape !!  
+    var_ret=walker.out(args_vtr[2]);
+    
+    for(idx=0; idx<var_ret->nbr_dim;idx++)
+      cst_vtr.push_back(var_ret->dim[idx]->nm);
+
+    var_ret=ncap_cst_mk(cst_vtr,prs_arg);
+    // convert to type of first arg
+    var_ret=nco_var_cnf_typ(var1->type,var_ret); 
+
   }
 
   if(prs_arg->ntl_scn){
