@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco.h,v 1.162 2011/02/21 22:38:42 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco.h,v 1.166 2012/01/01 20:51:53 zender Exp $ */
 
 /* Purpose: netCDF Operator (NCO) definitions */
 
-/* Copyright (C) 1995--2011 Charlie Zender
+/* Copyright (C) 1995--2012 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -122,6 +122,12 @@ extern "C" {
   /* Argument to strtol() and strtoul() indicating base-10 conversions */
 #define NCO_SNG_CNV_BASE10 10
 
+  /* netCDF provides no guidance on maximum nesting of groups */
+#define NCO_MAX_GRP_DEPTH 10
+
+  /* Flag that iterator found no more groups in container */
+#define NCO_LST_GRP 0
+
   /* Debugging level that quiets all non-requested informational messages
      This value is compared against user-selected dbg_lvl 
      Running operators with --quiet automatically sets dbg_lvl=NCO_DBG_QUIET */
@@ -449,8 +455,12 @@ extern "C" {
   
   /* Name ID structure */
   typedef struct{ /* nm_id_sct */
-    char *nm;
-    int id;
+    char *grp_nm; /* Group (stub name) where variable resides */
+    char *grp_nm_fll; /* Fully qualified group where variable resides */
+    char *var_nm_fll; /* Fully qualified variable name */
+    char *nm; /* Variable (stub name) */
+    int id; /* [id] Variable ID */
+    int grp_id; /* [ID] Group ID */
   } nm_id_sct;
   
   /* Rename structure */
