@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_att_utl.c,v 1.112 2011/03/18 23:11:13 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_att_utl.c,v 1.115 2012/01/01 20:51:53 zender Exp $ */
 
 /* Purpose: Attribute utilities */
 
-/* Copyright (C) 1995--2011 Charlie Zender
+/* Copyright (C) 1995--2012 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -48,7 +48,7 @@ nco_aed_prc /* [fnc] Process single attribute edit for single variable */
     (void)nco_inq_var(nc_id,var_id,var_nm,(nc_type *)NULL,(int *)NULL,(int *)NULL,&nbr_att);
   } /* end else */
 
-  if(dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stdout,"%s: INFO nco_aed_prc() examining variable %s\n",prg_nm_get(),var_nm);
+  if(dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stdout,"%s: INFO %s examining variable %s\n",prg_nm_get(),fnc_nm,var_nm);
 
   /* Query attribute metadata when attribute name was specified */
   if(aed.att_nm) rcd_inq_att=nco_inq_att_flg(nc_id,var_id,aed.att_nm,&att_typ,&att_sz);
@@ -110,7 +110,7 @@ nco_aed_prc /* [fnc] Process single attribute edit for single variable */
       
     /* Place nco_var_get() code inline since var struct is not truly complete */
     if((var->val.vp=(void *)nco_malloc_flg(var->sz*nco_typ_lng(var->type))) == NULL){
-      (void)fprintf(stdout,"%s: ERROR Unable to malloc() %ld*%lu bytes in nco_aed_prc()\n",prg_nm_get(),var->sz,(unsigned long)nco_typ_lng(var->type));
+      (void)fprintf(stdout,"%s: ERROR Unable to malloc() %ld*%lu bytes in %s\n",prg_nm_get(),var->sz,(unsigned long)nco_typ_lng(var->type),fnc_nm);
       nco_exit(EXIT_FAILURE); 
     } /* end if */
     if(var->sz > 1L){
@@ -125,7 +125,7 @@ nco_aed_prc /* [fnc] Process single attribute edit for single variable */
 
     /* Sanity check */
     if(var->has_mss_val == False){
-      (void)fprintf(stdout,"%s: ERROR variable %s does not have \"%s\" attribute in nco_aed_prc()\n",prg_nm_get(),var_nm,nco_mss_val_sng_get());
+      (void)fprintf(stdout,"%s: ERROR variable %s does not have \"%s\" attribute in %s\n",prg_nm_get(),var_nm,nco_mss_val_sng_get(),fnc_nm);
       nco_exit(EXIT_FAILURE);
     } /* end if */
 
@@ -243,31 +243,31 @@ nco_aed_prc /* [fnc] Process single attribute edit for single variable */
       att_val_new=nco_free(att_val_new);
     }else{
       /* Create new attribute */
-      rcd=nco_put_att(nc_id,var_id,aed.att_nm,aed.type,aed.sz,aed.val.vp);
+      rcd+=nco_put_att(nc_id,var_id,aed.att_nm,aed.type,aed.sz,aed.val.vp);
     } /* end else */
     break;
   case aed_create:	
-    if(rcd_inq_att != NC_NOERR) rcd=nco_put_att(nc_id,var_id,aed.att_nm,aed.type,aed.sz,aed.val.vp);  
+    if(rcd_inq_att != NC_NOERR) rcd+=nco_put_att(nc_id,var_id,aed.att_nm,aed.type,aed.sz,aed.val.vp);  
     break;
   case aed_delete:	
     /* Delete specified attribute if attribute name was specified... */
     if(aed.att_nm){
       /* ...and if attribute is known to exist from previous inquire call... */
-      if(rcd_inq_att == NC_NOERR) rcd=nco_del_att(nc_id,var_id,aed.att_nm);
+      if(rcd_inq_att == NC_NOERR) rcd+=nco_del_att(nc_id,var_id,aed.att_nm);
     }else{
       /* ...else delete all attributes for this variable... */
       while(nbr_att){
-	rcd=nco_inq_attname(nc_id,var_id,nbr_att-1,att_nm);
-	rcd=nco_del_att(nc_id,var_id,att_nm);
+	rcd+=nco_inq_attname(nc_id,var_id,nbr_att-1,att_nm);
+	rcd+=nco_del_att(nc_id,var_id,att_nm);
 	nbr_att--;
       } /* end while */
     } /* end else */
     break;
   case aed_modify:	
-    if(rcd_inq_att == NC_NOERR) rcd=nco_put_att(nc_id,var_id,aed.att_nm,aed.type,aed.sz,aed.val.vp);
+    if(rcd_inq_att == NC_NOERR) rcd+=nco_put_att(nc_id,var_id,aed.att_nm,aed.type,aed.sz,aed.val.vp);
     break;
   case aed_overwrite:	
-    rcd=nco_put_att(nc_id,var_id,aed.att_nm,aed.type,aed.sz,aed.val.vp);  
+    rcd+=nco_put_att(nc_id,var_id,aed.att_nm,aed.type,aed.sz,aed.val.vp);  
     break;
   default: 
     break;
@@ -275,12 +275,14 @@ nco_aed_prc /* [fnc] Process single attribute edit for single variable */
 
 #ifdef NCO_NETCDF4_AND_FILLVALUE
   if(flg_netCDF4_rename_trick){
-    rcd=nco_rename_att(nc_id,var_id,att_nm_tmp,nco_mss_val_sng_get());
+    rcd+=nco_rename_att(nc_id,var_id,att_nm_tmp,nco_mss_val_sng_get());
     /* Restore original name (space already allocated) */
     strcpy(aed.att_nm,nco_mss_val_sng_get()); 
   } /* !flg_netCDF4_rename_trick */
 #endif /* !NCO_NETCDF4_AND_FILLVALUE */
 
+  if(rcd != NC_NOERR) (void)fprintf(stdout,"%s: DEBUG WARNING %s reports unexpected cumulative rcd = %i on exit. Please report this to NCO project.\n",prg_nm_get(),fnc_nm,rcd);
+
 } /* end nco_aed_prc() */
 
 void 
@@ -305,22 +307,37 @@ nco_att_cpy  /* [fnc] Copy attributes from input netCDF file to output netCDF fi
 
   if(var_in_id == NC_GLOBAL){
     (void)nco_inq_natts(in_id,&nbr_att);
+    if(nbr_att > NC_MAX_ATTRS) (void)fprintf(stdout,"%s: WARNING Number of global attributes is %d which exceeds number permitted by netCDF NC_MAX_ATTRS = %d\n",prg_nm_get(),nbr_att,NC_MAX_ATTRS);
   }else{
     (void)nco_inq_varnatts(in_id,var_in_id,&nbr_att);
+    if(nbr_att > 0) (void)nco_inq_varname(out_id,var_out_id,var_nm);
+    if(nbr_att > NC_MAX_ATTRS) (void)fprintf(stdout,"%s: WARNING Variable %s has %d attributes which exceeds number permitted by netCDF NC_MAX_ATTRS = %d\n",prg_nm_get(),var_nm,nbr_att,NC_MAX_ATTRS);
   } /* end else */
-  
+
   /* Jump back to here if current attribute is treated specially */
   for(idx=0;idx<nbr_att;idx++){
     (void)nco_inq_attname(in_id,var_in_id,idx,att_nm);
     /* Look for same attribute in output variable in output file */
     rcd=nco_inq_att_flg(out_id,var_out_id,att_nm,(nc_type *)NULL,(long *)NULL);
       
-    /* If instructed not to copy packing attributes... */
-    if(!PCK_ATT_CPY)
-      /* ...and attribute is "scale_factor" or "add_offset" ... */
-      if(!strcmp(att_nm,"scale_factor") || !strcmp(att_nm,"add_offset"))
+    /* If attribute is "scale_factor" or "add_offset" ... */
+    if(!strcmp(att_nm,"scale_factor") || !strcmp(att_nm,"add_offset")){
+      /* ...and if instructed to copy packing attributes... */
+      if(PCK_ATT_CPY){
+	int prg_id; /* [enm] Program ID */
+	prg_id=prg_get(); /* [enm] Program ID */
+	/* ...and if multifile concatenator (ncrcat, ncecat)... */
+	if(prg_id == ncrcat || prg_id == ncecat){
+	  /* ...then risk exists that packing attributes in first file do not match subsequent files... */
+	  static short FIRST_WARNING=True;
+	  if(FIRST_WARNING) (void)fprintf(stderr,"%s: INFO/WARNING Multi-file concatenator encountered packing attribute %s for variable %s. NCO copies the packing attributes from the first file to the output file. The packing attributes from the remaining files must match exactly those in the first file or the data from the subsequent files will not be unpacked correctly. Be sure that all input files share the same packing attributes. If in doubt, unpack (with ncpdq -U) the input files, then concatenate them, then pack the result (with ncpdq). This message is printed only once per invocation.\n",prg_nm_get(),att_nm,var_nm);
+	  FIRST_WARNING=False;
+	} /* endif ncrcat or ncecat */
+      }else{ /* ...do not copy packing attributes... */
 	/* ...then skip remainder of loop, thereby skipping attribute copy... */
 	continue;
+      } /* endelse */
+    } /* endif attribute is "scale_factor" or "add_offset" */
     
     /* Inform user when copy will overwrite an existing attribute */
     if(dbg_lvl_get() >= nco_dbg_std){
@@ -328,7 +345,6 @@ nco_att_cpy  /* [fnc] Copy attributes from input netCDF file to output netCDF fi
 	if(var_out_id == NC_GLOBAL){
 	  (void)fprintf(stderr,"%s: INFO Overwriting global attribute %s\n",prg_nm_get(),att_nm);
 	}else{
-	  (void)nco_inq_varname(out_id,var_out_id,var_nm);
 	  (void)fprintf(stderr,"%s: INFO Overwriting attribute %s for output variable %s\n",prg_nm_get(),att_nm,var_nm);
 	} /* end else */
       } /* end if */
