@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.c,v 1.32 2010/12/21 20:12:07 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.c,v 1.34 2012/02/13 23:09:50 zender Exp $ */
 
 /* Purpose: NCO utilities for chunking */
 
-/* Copyright (C) 1995--2011 Charlie Zender
+/* Copyright (C) 1995--2012 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -574,10 +574,9 @@ nco_cnk_dsk_inq /* [fnc] Check whether variable is chunked on disk */
   /* Purpose: Check whether variable is chunked on disk */
   /* ncea -O -D 3 -v cnk ~/nco/data/in.nc ~/nco/data/foo.nc */
   
-  int rcd; /* [rcd] Return success code */
   int srg_typ; /* [enm] Storage type */
   
-  rcd=nco_inq_var_chunking(nc_id,var_id,&srg_typ,(size_t *)NULL);
+  (void)nco_inq_var_chunking(nc_id,var_id,&srg_typ,(size_t *)NULL);
 
   if(srg_typ == NC_CONTIGUOUS) return False; else return True;
   
