@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_cnv_csm.c,v 1.54 2011/01/01 02:28:48 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_cnv_csm.c,v 1.56 2012/01/01 20:51:53 zender Exp $ */
 
 /* Purpose: CCM/CCSM/CF conventions */
 
-/* Copyright (C) 1995--2011 Charlie Zender
+/* Copyright (C) 1995--2012 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -121,11 +121,7 @@ nco_cnv_ccm_ccsm_cf_date /* [fnc] Fix date variable in averaged CCM/CCSM/CF file
   day=(nco_int)(var[time_idx]->val.dp[0]);
   
   /* Recompute date variable based on new (averaged) day number */
-#ifdef USE_FORTRAN_ARITHMETIC
-  date=FORTRAN_newdate(&nbdate,&day);
-#else /* !USE_FORTRAN_ARITHMETIC */
   date=nco_newdate(nbdate,day);
-#endif /* !USE_FORTRAN_ARITHMETIC */
   if(var[date_idx]->type == NC_INT){
     if(!var[date_idx]->val.ip) return; else var[date_idx]->val.ip[0]=date;
   }else if(var[date_idx]->type == NC_DOUBLE){
