@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_lst_utl.h,v 1.38 2010/12/21 20:12:07 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_lst_utl.h,v 1.44 2012/02/14 01:10:05 zender Exp $ */
 
 /* Purpose: List utilities */
 
-/* Copyright (C) 1995--2011 Charlie Zender
+/* Copyright (C) 1995--2012 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -12,11 +12,23 @@
 #ifndef NCO_LST_UTL_H
 #define NCO_LST_UTL_H
 
+#ifdef HAVE_CONFIG_H
+# include <config.h> /* Autotools tokens */
+#endif /* !HAVE_CONFIG_H */
+
 /* Standard header files */
 #include <stdio.h> /* stderr, FILE, NULL, printf */
 #include <stdlib.h> /* strtod, strtol, malloc, getopt, qsort */
 #include <string.h> /* strcmp. . . */
 
+#ifdef HAVE_REGEX_H 
+/* 20120213: Linux GCC 4.6 man page says regex.h depends on (non-present) sys/types.h */
+# ifdef MACOSX
+#  include <sys/types.h> /* 20040822: Provide off_t required by Mac OS X regex.h */
+# endif /* !MACOSX */
+# include <regex.h> /* POSIX regular expressions library */
+#endif /* HAVE_REGEX_H */
+
 /* 3rd party vendors */
 #include <netcdf.h> /* netCDF definitions and C library */
 #include "nco_netcdf.h" /* NCO wrappers for netCDF C library */
@@ -31,6 +43,13 @@
 extern "C" {
 #endif /* __cplusplus */
 
+int /* O [nbr] Number of matches found */
+nco_lst_meta_search /* [fnc] Search for pattern matches in var string list */
+(int var_nbr_all, /* I [nbr] Size of var_lst_all and var_xtr_rqs */
+ nm_id_sct *var_lst_all, /* I [sct] All variables in input file (with IDs) */
+ char *rx_sng, /* I [sng] Regular expression pattern */
+ nco_bool *var_xtr_rqs); /* O [flg] Matched vars holder */
+
 void 
 nco_srt_ntg /* [fnc] Sort array of integers */
 (const int lmn_nbr, /* I [nbr] Number of elements */
@@ -61,8 +80,6 @@ nco_lst_prs_sgl_2D /* [fnc] Create list of strings from given string and delimit
  const char * const dlm_sng, /* I [sng] Delimiter string */
  int * const nbr_lst); /* O [nbr] Number of elements in list */
 
-
-
 nm_id_sct * /* O [sct] Sorted output list */
 lst_heapsort /* [fnc] Heapsort input lists numerically or alphabetically */
 (nm_id_sct *lst, /* I/O [sct] Current list (destroyed) */
