@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_mmr.h,v 1.27 2010/12/21 20:12:07 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_mmr.h,v 1.30 2012/02/14 01:10:05 zender Exp $ */
 
 /* Purpose: Memory management */
 
-/* Copyright (C) 1995--2011 Charlie Zender
+/* Copyright (C) 1995--2012 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -12,6 +12,10 @@
 #ifndef NCO_MMR_H
 #define NCO_MMR_H
 
+#ifdef HAVE_CONFIG_H
+# include <config.h> /* Autotools tokens */
+#endif /* !HAVE_CONFIG_H */
+
 /* Standard header files */
 #include <errno.h> /* system/library error diagnostics, errno */
 #include <stdio.h> /* stderr, FILE, NULL, printf */
@@ -20,7 +24,9 @@
 #ifdef MACOSX
 # include <sys/time.h> /* machine time (needed by Mac OS X for struct rusage) */ 
 #endif /* !MACOSX */
-#include <sys/resource.h> /* Resource usage and limits */
+#ifdef HAVE_GETRUSAGE
+# include <sys/resource.h> /* Resource usage and limits */
+#endif /* !HAVE_GETRUSAGE */
 
 /* 3rd party vendors */
 #include <netcdf.h> /* netCDF definitions and C library */
