@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_netcdf.c,v 1.137 2011/02/21 23:38:00 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_netcdf.c,v 1.146 2012/01/01 20:51:53 zender Exp $ */
 
 /* Purpose: NCO wrappers for netCDF C library */
 
-/* Copyright (C) 1995--2011 Charlie Zender
+/* Copyright (C) 1995--2012 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -83,8 +83,9 @@ nco_err_exit /* [fnc] Print netCDF error message, routine name, then exit */
 #endif /* !NCO_ABORT_ON_ERROR */
 
   switch(rcd){
+  case NC_ENOTNC: (void)fprintf(stdout,"ERROR NC_ENOTNC Not a netCDF file\nHINT: NC_ENOTNC errors will occur when NCO operators linked to the netCDF3 library attempt to read netCDF4 files.  Are your input files netCDF4 format?  (http://nco.sf.net/nco.html#fmt_inq shows how to tell.) If so then installing or re-building a netCDF4-compatible version of NCO should solve this problem. First upgrade netCDF to version 4.x, then install NCO using those netCDF 4.x libraries.\n"); break;
   case NC_ERANGE: (void)fprintf(stdout,"ERROR NC_ERANGE Result not representable in output file\nHINT: NC_ERANGE errors typically occur after an arithmetic operation results in a value not representible by the output variable type when NCO attempts to write those values to an output file.  Possible workaround: Promote the variable to higher precision before attempting arithmetic.  For example,\nncap2 -O -s \'foo=double(foo);\' in.nc in.nc\nFor more details, see http://nco.sf.net/nco.html#typ_cnv\n"); break;
-  case NC_ENOTNC: (void)fprintf(stdout,"ERROR NC_ENOTNC Not a netCDF file\nHINT: NC_ENOTNC errors will occur when NCO operators linked to the netCDF3 library attempt to read netCDF4 files.  Are your input files netCDF4 format?  (http://nco.sf.net/nco.html#fmt_inq shows how to tell.) If so then installing or re-building a netCDF4-compatible version of NCO should solve this problem.\n"); break;
+  case NC_EVARSIZE: (void)fprintf(stdout,"ERROR NC_EVARSIZE One or more variable sizes violate format constraints\nHINT: NC_EVARSIZE errors can occur when attempting to aggregate netCDF3 classic files together into outputs that exceed the capacity of the netCDF3 classic file format, e.g., a variable with size in excess of 2^31 bytes. In this case, try altering the output file type to netCDF3 classic with 64-bit offsets (with --64) or to netCDF4 (with -4). For more details, see http://nco.sf.net/nco.html#fl_fmt\n"); break;
   } /* end switch */
 
   /* Print NCO-generated error message, if any */
@@ -557,7 +558,19 @@ nco_inq_format(const int nc_id,int * const fl_fmt)
   rcd=nc_inq_format(nc_id,fl_fmt);
   if(rcd != NC_NOERR) nco_err_exit(rcd,"nco_inq_format()");
   return rcd;
-} /* end nco_inq_format */
+} /* end nco_inq_format() */
+
+#ifdef ENABLE_NETCDF4
+int
+nco_inq_ncid(const int nc_id,const char * const grp_nm,int * const grp_id)
+{
+  /* Purpose: Wrapper for nc_inq_ncid() */
+  int rcd;
+  rcd=nc_inq_ncid(nc_id,grp_nm,grp_id);
+  if(rcd != NC_NOERR) nco_err_exit(rcd,"nco_inq_ncid()");
+  return rcd;
+} /* end nco_inq_ncid() */
+#endif /* !ENABLE_NETCDF4 */
 
 int
 nco_inq_ndims(const int nc_id,int * const dmn_nbr_fl)
@@ -567,7 +580,7 @@ nco_inq_ndims(const int nc_id,int * const dmn_nbr_fl)
   rcd=nc_inq_ndims(nc_id,dmn_nbr_fl);
   if(rcd != NC_NOERR) nco_err_exit(rcd,"nco_inq_ndims()");
   return rcd;
-} /* end nco_inq_ndims */
+} /* end nco_inq_ndims() */
 
 int
 nco_inq_nvars(const int nc_id,int * const var_nbr_fl)
@@ -577,7 +590,7 @@ nco_inq_nvars(const int nc_id,int * const var_nbr_fl)
   rcd=nc_inq_nvars(nc_id,var_nbr_fl);
   if(rcd != NC_NOERR) nco_err_exit(rcd,"nco_inq_nvars()");
   return rcd;
-} /* end nco_inq_nvars */
+} /* end nco_inq_nvars() */
 
 int
 nco_inq_natts(const int nc_id,int * const att_glb_nbr)
@@ -587,7 +600,7 @@ nco_inq_natts(const int nc_id,int * const att_glb_nbr)
   rcd=nc_inq_natts(nc_id,att_glb_nbr);
   if(rcd != NC_NOERR) nco_err_exit(rcd,"nco_inq_natts()");
   return rcd;
-} /* end nco_inq_natts */
+} /* end nco_inq_natts() */
 
 int
 nco_inq_unlimdim(const int nc_id,int * const rec_dmn_id)
@@ -597,9 +610,114 @@ nco_inq_unlimdim(const int nc_id,int * const rec_dmn_id)
   rcd=nc_inq_unlimdim(nc_id,rec_dmn_id);
   if(rcd != NC_NOERR) nco_err_exit(rcd,"nco_inq_unlimdim()");
   return rcd;
-} /* end nco_inq_unlimdim */
+} /* end nco_inq_unlimdim() */
+
+int
+nco_inq_unlimdim_flg(const int nc_id,int * const rec_dmn_id)
+{
+  /* Purpose: Error-tolerant wrapper for nc_inq_unlimdim(). Tolerates NC_EBADDIM. */
+  int rcd;
+  rcd=nc_inq_unlimdim(nc_id,rec_dmn_id);
+  if(rcd == NC_EBADDIM) return rcd;
+  if(rcd != NC_NOERR) nco_err_exit(rcd,"nco_inq_unlimdim_flg()");
+  return rcd;
+} /* end nco_inq_unlimdim_flg() */
 /* End File routines */
 
+/* Begin Group routines (_grp) */
+#ifdef ENABLE_NETCDF4
+int nco_def_grp(const int nc_id,const char * const grp_nm,int * const grp_id)
+{
+  /* Purpose: Wrapper for nc_def_grp() */
+  int rcd;
+  rcd=nc_def_grp(nc_id,grp_nm,grp_id);
+  if(rcd != NC_NOERR) nco_err_exit(rcd,"nco_def_grp()");
+  return rcd;
+} /* end nco_def_grp() */
+
+int nco_inq_dimids(const int nc_id,int * const dmn_nbr,int * const dmn_ids,int flg_prn)
+{
+  /* Purpose: Wrapper for nc_inq_dimids() */
+  int rcd;
+  rcd=nc_inq_dimids(nc_id,dmn_nbr,dmn_ids,flg_prn);
+  if(rcd != NC_NOERR) nco_err_exit(rcd,"nco_inq_dimids()");
+  return rcd;
+} /* end nco_inq_dimids() */
+
+int nco_inq_grpname(const int nc_id,char * const grp_nm)
+{
+  /* Purpose: Wrapper for nc_inq_grpname() */
+  int rcd;
+  rcd=nc_inq_grpname(nc_id,grp_nm);
+  if(rcd != NC_NOERR) nco_err_exit(rcd,"nco_inq_grpname()");
+  return rcd;
+} /* end nco_inq_grpname() */
+
+int nco_inq_grpname_full(const int nc_id,size_t * grp_nm_lng,char * const grp_nm_full)
+{
+  /* Purpose: Wrapper for nc_inq_grpname_full() */
+  int rcd;
+  rcd=nc_inq_grpname_full(nc_id,grp_nm_lng,grp_nm_full);
+  if(rcd != NC_NOERR) nco_err_exit(rcd,"nco_inq_grpname_full()");
+  return rcd;
+} /* end nco_inq_grpname_full() */
+
+int nco_inq_grpname_len(const int nc_id,size_t * const grp_nm_lng)
+{
+  /* Purpose: Wrapper for nc_inq_grpname_len() */
+  int rcd;
+  rcd=nc_inq_grpname_len(nc_id,grp_nm_lng);
+  if(rcd != NC_NOERR) nco_err_exit(rcd,"nco_inq_grpname_len()");
+  return rcd;
+} /* end nco_inq_grpname_len() */
+
+int nco_inq_grps(const int nc_id,int * const grp_nbr,int * const grp_ids)
+{
+  /* Purpose: Wrapper for nc_inq_grps() */
+  int rcd;
+  rcd=nc_inq_grps(nc_id,grp_nbr,grp_ids);
+  if(rcd != NC_NOERR) nco_err_exit(rcd,"nco_inq_grps()");
+  return rcd;
+} /* end nco_inq_grps() */
+
+int nco_inq_grp_ncid(const int nc_id,char * const grp_nm,int * const grp_id)
+{
+  /* Purpose: Wrapper for nc_inq_grp_ncid() */
+  int rcd;
+  rcd=nc_inq_grp_ncid(nc_id,grp_nm,grp_id);
+  if(rcd != NC_NOERR) nco_err_exit(rcd,"nco_inq_grp_ncid()");
+  return rcd;
+} /* end nco_inq_grp_ncid() */
+
+int nco_inq_grp_full_ncid(const int nc_id,char * const grp_nm_fll,int * const grp_id)
+{
+  /* Purpose: Wrapper for nc_inq_grp_full_ncid() */
+  int rcd;
+  rcd=nc_inq_grp_full_ncid(nc_id,grp_nm_fll,grp_id);
+  if(rcd != NC_NOERR) nco_err_exit(rcd,"nco_inq_grp_full_ncid()");
+  return rcd;
+} /* end nco_inq_grp_full_ncid() */
+
+int nco_inq_grp_parent(const int nc_id,int * const prn_id)
+{
+  /* Purpose: Wrapper for nc_inq_grp_parent() */
+  int rcd;
+  rcd=nc_inq_grp_parent(nc_id,prn_id);
+  if(rcd != NC_NOERR) nco_err_exit(rcd,"nco_inq_grp_parent()");
+  return rcd;
+} /* end nco_inq_grp_parent() */
+
+int nco_inq_varids(const int nc_id,int * const var_nbr,int * const var_ids)
+{
+  /* Purpose: Wrapper for nc_inq_varids() */
+  int rcd;
+  rcd=nc_inq_varids(nc_id,var_nbr,var_ids);
+  if(rcd != NC_NOERR) nco_err_exit(rcd,"nco_inq_varids()");
+  return rcd;
+} /* end nco_inq_varids() */
+#endif /* !ENABLE_NETCDF4 */
+/* End Group routines */
+
 /* Begin Dimension routines (_dim) */
 int
 nco_def_dim(const int nc_id,const char * const dmn_nm,const long dmn_sz,int * const dmn_id)
@@ -898,7 +1016,7 @@ nco_inq_varid(const int nc_id,const char * const var_nm,int * const var_id)
 int
 nco_inq_varid_flg(const int nc_id,const char * const var_nm,int * const var_id)
 {
-  /* Purpose: Error-tolerant wrapper for nc_inq_varid_flg(). Tolerates NC_ENOTVAR. */
+  /* Purpose: Error-tolerant wrapper for nc_inq_varid(). Tolerates NC_ENOTVAR. */
   int rcd;
   rcd=nc_inq_varid(nc_id,var_nm,var_id);
   if(rcd == NC_ENOTVAR) return rcd;
