@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_netcdf.h,v 1.74 2010/12/21 20:12:07 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_netcdf.h,v 1.80 2012/01/01 20:51:53 zender Exp $ */
 
 /* Purpose: NCO wrappers for netCDF C library */
 
-/* Copyright (C) 1995--2011 Charlie Zender
+/* Copyright (C) 1995--2012 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -107,12 +107,31 @@ int nco_inq(const int nc_id,int * const dmn_nbr_fl,int * const var_nbr_fl,int *
 int nc_inq_format(int nc_id, int * const fl_fmt);
 #endif /* !NEED_NC_INQ_FORMAT */
 int nco_inq_format(const int nc_id,int * const fl_fmt);
+#ifdef ENABLE_NETCDF4
+int nco_inq_ncid(const int nc_id,const char * const grp_nm,int * const grp_id);
+#endif /* !ENABLE_NETCDF4 */
 int nco_inq_ndims(const int nc_id,int * const dmn_nbr_fl);
 int nco_inq_nvars(const int nc_id,int * const var_nbr_fl);
 int nco_inq_natts(const int nc_id,int * const att_glb_nbr);
 int nco_inq_unlimdim(const int nc_id,int * const rec_dmn_id);
+int nco_inq_unlimdim_flg(const int nc_id,int * const rec_dmn_id);
 /* End File routines */
 
+/* Begin Group routines (_grp) */
+#ifdef ENABLE_NETCDF4
+int nco_def_grp(const int nc_id,const char * const grp_nm,int * const grp_id);
+int nco_inq_dimids(const int nc_id,int * const dmn_nbr,int * const dmn_ids,int flg_prn);
+int nco_inq_grpname(const int nc_id,char * const grp_nm);
+int nco_inq_grpname_full(const int nc_id,size_t * grp_nm_lng,char * const grp_nm_fll);
+int nco_inq_grpname_len(const int nc_id,size_t * const grp_nm_lng);
+int nco_inq_grps(const int nc_id,int * const grp_nbr,int * const grp_ids);
+int nco_inq_grp_full_ncid(const int nc_id,char * const grp_nm_fll,int * const grp_id);
+int nco_inq_grp_ncid(const int nc_id,char * const grp_nm,int * const grp_id);
+int nco_inq_grp_parent(const int nc_id,int * const prn_id);
+int nco_inq_varids(const int nc_id,int * const var_nbr,int * const var_ids);
+#endif /* !ENABLE_NETCDF4 */
+/* End Group routines */
+
 /* Begin Dimension routines (_dim) */
 int nco_def_dim(const int nc_id,const char * const dmn_nm,const long dmn_sz,int * const dmn_id);
 int nco_inq_dimid(const int nc_id,const char * const dmn_nm,int * const dmn_id);
