@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_prn.c,v 1.70 2011/04/20 16:59:08 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_prn.c,v 1.72 2012/01/01 20:51:53 zender Exp $ */
 
 /* Purpose: Printing variables, attributes, metadata */
 
-/* Copyright (C) 1995--2011 Charlie Zender
+/* Copyright (C) 1995--2012 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -257,11 +257,11 @@ nco_prn_var_dfn /* [fnc] Print variable metadata */
        NCO wrappers perform no-ops on netCDF3 files */
     rcd=nco_inq_var_deflate(in_id,var_id,&shuffle,&deflate,&dfl_lvl);
     if(deflate) (void)fprintf(stdout,"%s on-disk compression (Lempel-Ziv %s shuffling) level = %d\n",var_nm,(shuffle) ? "with" : "without",dfl_lvl);
-    (void)fprintf(stdout,"%s RAM size is %s = %li*%lu = %lu bytes\n",var_nm,sz_sng,var_sz,(unsigned long)nco_typ_lng(var_typ),(unsigned long)(var_sz*nco_typ_lng(var_typ)));
+    (void)fprintf(stdout,"%s size (in RAM) is %s = %li*%lu = %lu bytes\n",var_nm,sz_sng,var_sz,(unsigned long)nco_typ_lng(var_typ),(unsigned long)(var_sz*nco_typ_lng(var_typ)));
   }else{
     long var_sz=1L;
 
-    (void)fprintf(stdout,"%s RAM size is %ld*sizeof(%s) = %ld*%lu = %lu bytes\n",var_nm,var_sz,nco_typ_sng(var_typ),var_sz,(unsigned long)nco_typ_lng(var_typ),(unsigned long)(var_sz*nco_typ_lng(var_typ)));
+    (void)fprintf(stdout,"%s size (in RAM) is %ld*sizeof(%s) = %ld*%lu = %lu bytes\n",var_nm,var_sz,nco_typ_sng(var_typ),var_sz,(unsigned long)nco_typ_lng(var_typ),(unsigned long)(var_sz*nco_typ_lng(var_typ)));
   } /* end if variable is scalar */
 
   /* Print dimension sizes and names */
@@ -281,7 +281,7 @@ nco_prn_var_dfn /* [fnc] Print variable metadata */
   } /* end loop over dim */
   
   /* Caveat user */
-  if((nc_type)var_typ == NC_STRING) (void)fprintf(stdout,"%s RAM size above is space required for pointers only, full size of strings is unknown until data are read\n",var_nm);
+  if((nc_type)var_typ == NC_STRING) (void)fprintf(stdout,"%s size (in RAM) above is space required for pointers only, full size of strings is unknown until data are read\n",var_nm);
   (void)fflush(stdout);
   
   /* Free space allocated for dimension information */
