@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_rth_utl.h,v 1.22 2010/12/21 20:12:07 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_rth_utl.h,v 1.25 2012/01/01 20:51:53 zender Exp $ */
 
 /* Purpose: Arithmetic controls and utilities */
 
-/* Copyright (C) 1995--2011 Charlie Zender
+/* Copyright (C) 1995--2012 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -13,6 +13,7 @@
 #define NCO_RTH_UTL_H
 
 /* Standard header files */
+#include <math.h> /* sin cos cos sin 3.14159 */
 #include <stdio.h> /* stderr, FILE, NULL, printf */
 #include <stdlib.h> /* strtod, strtol, malloc, getopt, exit */
 #include <string.h> /* strcmp. . . */
@@ -65,6 +66,12 @@ nco_zero_long /* [fnc] Zero all values of long array */
 (const long sz, /* I [nbr] Size (in elements) of operand */
  long * restrict const op1); /* I/O [nbr] Array to be zeroed */
 
+void
+nco_set_long /* [fnc] Set all values of long array */
+(const long sz, /* I [nbr] Size (in elements) of operand */
+ const long val, /* I [] Number to set array to */
+ long * restrict const op1); /* I/O [nbr] Array to be set */
+
 #ifdef __cplusplus
 } /* end extern "C" */
 #endif /* __cplusplus */
