@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_var_lst.h,v 1.51 2011/03/04 21:42:38 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_var_lst.h,v 1.56 2012/02/14 01:10:05 zender Exp $ */
 
 /* Purpose: Variable list utilities */
 
-/* Copyright (C) 1995--2011 Charlie Zender
+/* Copyright (C) 1995--2012 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -21,11 +21,12 @@
 #include <stdlib.h> /* strtod, strtol, malloc, getopt, exit */
 #include <string.h> /* strcmp. . . */
 
-#ifdef HAVE_REGEX_H
-#ifdef MACOSX
-#include <sys/types.h> /* 20040822: Provide off_t required by Mac OS X regex.h */
-#endif /* !MACOSX */
-#include <regex.h> /* POSIX regular expressions library */
+#ifdef HAVE_REGEX_H 
+/* 20120213: Linux GCC 4.6 man page says regex.h depends on (non-present) sys/types.h */
+# ifdef MACOSX
+#  include <sys/types.h> /* 20040822: Provide off_t required by Mac OS X regex.h */
+# endif /* !MACOSX */
+# include <regex.h> /* POSIX regular expressions library */
 #endif /* HAVE_REGEX_H */
 
 /* 3rd party vendors */
@@ -46,11 +47,11 @@ extern "C" {
 nm_id_sct * /* O [sct] Variable extraction list */
 nco_var_lst_mk /* [fnc] Create variable extraction list */
 (const int nc_id, /* I [enm] netCDF file ID */
- const int nbr_var, /* I [nbr] Number of variables in input file */
+ const int var_nbr_all, /* I [nbr] Number of variables in input file */
  char * const * const var_lst_in, /* I [sng] User-specified list of variable names and rx's */
  const nco_bool EXCLUDE_INPUT_LIST, /* I [flg] Exclude rather than extract */
  const nco_bool EXTRACT_ALL_COORDINATES, /* I [flg] Process all coordinates */
- int * const nbr_xtr); /* I/O [nbr] Number of variables in current extraction list */
+ int * const var_nbr_xtr); /* I/O [nbr] Number of variables in current extraction list */
 
 nm_id_sct * /* O [sct] Extraction list */
 nco_var_lst_xcl /* [fnc] Convert exclusion list to extraction list */
@@ -126,13 +127,6 @@ nco_var_lst_mrg /* [fnc] Merge two variable lists into same order */
  int * const var_nbr_1, /* I/O [nbr] Number of variables in list 1 */
  int * const var_nbr_2); /* I/O [nbr] Number of variables in list 2 */
 
-int /* O [nbr] Number of matches found */
-nco_var_meta_search /* [fnc] Search for pattern matches in var string list */
-(int nbr_var, /* I [nbr] number of vars in srch_sng and size of var_xtr_rqs */
- nm_id_sct *fl_in_var_lst, /* I [sct] All variables in input file (with IDs) */
- char *rexp, /* I [sng] Regular expression pattern */
- nco_bool *var_xtr_rqs); /* O [flg] Matched vars holder */
-
 #ifdef __cplusplus
 } /* end extern "C" */
 #endif /* __cplusplus */
