@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_var_rth.c,v 1.55 2010/12/21 20:12:07 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_var_rth.c,v 1.59 2012/02/07 07:12:05 zender Exp $ */
 
 /* Purpose: Variable arithmetic */
 
-/* Copyright (C) 1995--2011 Charlie Zender
+/* Copyright (C) 1995--2012 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -110,7 +110,7 @@ nco_var_add /* [fnc] Add first operand to second operand */
      nco_var_add() does _not_ increment tally counter
      nco_var_add_tll_ncra() does increment tally counter */
   
-  /* Addition is currently defined as op2:=op1+op2 */
+  /* Addition is currently defined as op2:=op1+op2 where op1 != mss_val and op2 != mss_val */
   
   long idx;
   
@@ -228,7 +228,7 @@ nco_var_add_tll_ncflint /* [fnc] Add first operand to second operand, increment
      nco_var_add() does _not_ increment tally counter
      nco_var_add_tll_ncflint() does increment tally counter */
   
-  /* Addition is currently defined as op2:=op1+op2 */
+  /* Addition is currently defined as op2:=op1+op2 where op1 != mss_val and op2 != mss_val */
   
   long idx;
   
@@ -575,7 +575,7 @@ nco_var_add_tll_ncra /* [fnc] Add first operand to second operand, increment tal
      NCO uses nco_var_add_tll_ncflint() only for ncflint
      NCO uses nco_var_add_tll_ncra() only for ncra/ncea */
   
-  /* Addition is currently defined as op2:=op1+op2 */
+  /* Addition is currently defined as op2:=op1+op2 where op1 != mss_val */
   
   long idx;
   
@@ -725,6 +725,100 @@ nco_var_add_tll_ncra /* [fnc] Add first operand to second operand, increment tal
   
 } /* end nco_var_add_tll_ncra() */
 
+void 
+nco_var_copy_tll /* [fnc] Copy hyperslab variables of type var_typ from op1 to op2 */
+(const nc_type type, /* I [enm] netCDF type */
+ const long sz, /* I [nbr] Number of elements to copy */
+ const int has_mss_val, /* I [flg] Flag for missing values */
+ ptr_unn mss_val, /* I [val] Value of missing value */
+ long * restrict const tally, /* O [nbr] Counter space */
+ const ptr_unn op1, /* I [sct] Values to copy */
+ ptr_unn op2) /* O [sct] Destination to copy values to */
+{
+  /* Purpose: Copy hyperslab variables of type var_typ from op1 to op2
+     Assumes memory area in op2 has already been malloc()'d
+     Where the value copied is not equal to the missing value, set the tally to one
+     nco_var_copy(): Does nothing with missing values and tallies
+     nco_var_copy_tll(): Accounts for missing values in tally */
+
+  /* Algorithm is currently defined as: op2:=op1 */
+
+  long idx;
+
+  /* Use fast nco_var_copy() method to copy variable */
+  (void)memcpy((void *)(op2.vp),(void *)(op1.vp),sz*nco_typ_lng(type));
+
+  /* Tally is one if no missing value is defined */
+  (void)nco_set_long(sz,1L,tally);
+
+  if(!has_mss_val) return;
+
+  /* Typecast pointer to values before access */
+  (void)cast_void_nctype(type,&op2);
+  if(has_mss_val) (void)cast_void_nctype(type,&mss_val);
+
+  /* Overwrite one's with zero's where value equals missing value */
+  switch(type){
+  case NC_FLOAT:
+    {
+      const float mss_val_flt=*mss_val.fp;
+      for(idx=0;idx<sz;idx++) if(op2.fp[idx] == mss_val_flt) tally[idx]=0L;
+    }
+    break;
+  case NC_DOUBLE:
+    {
+      const double mss_val_dbl=*mss_val.dp;
+      for(idx=0;idx<sz;idx++) if(op2.dp[idx] == mss_val_dbl) tally[idx]=0L;
+    }
+    break;
+  case NC_INT:
+    {
+      const nco_int mss_val_ntg=*mss_val.ip;
+      for(idx=0;idx<sz;idx++) if(op2.ip[idx] == mss_val_ntg) tally[idx]=0L;
+    }
+    break;
+  case NC_SHORT:
+    {
+      const nco_short mss_val_short=*mss_val.sp;
+      for(idx=0;idx<sz;idx++) if(op2.sp[idx] == mss_val_short) tally[idx]=0L;
+    }
+    break;
+  case NC_USHORT:
+    {
+      const nco_ushort mss_val_ushort=*mss_val.usp;
+      for(idx=0;idx<sz;idx++) if(op2.usp[idx] == mss_val_ushort) tally[idx]=0L;
+    }
+    break;
+  case NC_UINT:
+    {
+      const nco_uint mss_val_uint=*mss_val.uip;
+      for(idx=0;idx<sz;idx++) if(op2.uip[idx] == mss_val_uint) tally[idx]=0L;
+    }
+    break;
+  case NC_INT64:
+    {
+      const nco_int64 mss_val_int64=*mss_val.i64p;
+      for(idx=0;idx<sz;idx++) if(op2.i64p[idx] == mss_val_int64) tally[idx]=0L;
+    }
+    break;
+  case NC_UINT64:
+    {
+      const nco_uint64 mss_val_uint64=*mss_val.ui64p;
+      for(idx=0;idx<sz;idx++) if(op2.ui64p[idx] == mss_val_uint64) tally[idx]=0L;
+    }
+    break;
+  case NC_BYTE: break; /* Do nothing */
+  case NC_UBYTE: break; /* Do nothing */
+  case NC_CHAR: break; /* Do nothing */
+  case NC_STRING: break; /* Do nothing */
+  default: nco_dfl_case_nc_type_err(); break;
+  } /* end switch */
+  
+  /* NB: it is not neccessary to un-typecast pointers to values after access 
+     because we have only operated on local copies of them. */
+
+} /* end nco_var_copy_tll() */
+
 void
 nco_var_dvd /* [fnc] Divide second operand by first operand */
 (const nc_type type, /* I [type] netCDF type of operands */
@@ -1392,7 +1486,7 @@ nco_var_msk /* [fnc] Mask third operand where first and second operands fail com
   nco_byte mss_val_byte=nco_byte_CEWI;
   nco_ubyte mss_val_ubyte=nco_ubyte_CEWI;
   nco_char mss_val_char=nco_char_CEWI;
-  nco_string mss_val_string=nco_string_CEWI;
+  /*  nco_string mss_val_string=nco_string_CEWI;*/ /* 20120206: mss_val_string is not yet used so do not define */
   
   /* Typecast pointer to values before access */
   (void)cast_void_nctype(type,&op2);
@@ -1417,7 +1511,7 @@ nco_var_msk /* [fnc] Mask third operand where first and second operands fail com
     case NC_BYTE: mss_val_byte=*mss_val.bp; break;
     case NC_UBYTE: mss_val_ubyte=*mss_val.ubp; break;
     case NC_CHAR: mss_val_char=*mss_val.cp; break;
-    case NC_STRING: mss_val_string=*mss_val.sngp; break;
+      /*    case NC_STRING: mss_val_string=*mss_val.sngp; break;*/ /* 20120206: mss_val_string is not yet used so do not define */
     default: nco_dfl_case_nc_type_err(); break;
     } /* end switch */
   } /* endif */
@@ -1543,6 +1637,96 @@ nco_var_msk /* [fnc] Mask third operand where first and second operands fail com
   
 } /* end nco_var_msk() */
 
+void
+nco_var_tll_zro_mss_val /* [fnc] Write missing value into elements with zero tally */
+(const nc_type type, /* I [enm] netCDF type of operand */
+ const long sz, /* I [nbr] Size (in elements) of operand */
+ const int has_mss_val, /* I [flg] Flag for missing values */
+ ptr_unn mss_val, /* I [val] Value of missing value */
+ const long * const tally, /* I [nbr] Counter to normalize by */
+ ptr_unn op1) /* I/O [val] Values of first operand on input, possibly missing values on output */
+{
+  /* Threads: Routine is thread safe and calls no unsafe routines */
+  /* Purpose: Write missing value into elements with zero tally
+     Routine is necessary because initialization of accumulating sums (specified, e.g., with -y ttl or with -N)
+     sets initial sum to zero (so augmenting works) regardless if first slice is missing.
+     Such sums are usually normalized and set to missing if tally is zero.
+     However, totals are integrals and thus are never normalized.
+     Initialization value of zero will be output even if tally is zero,
+     _unless field is processed with this routine after summing and prior to writing. */
+  
+  /* Filter currently works as op1:=mss_val where tally == 0 */
+  
+  long idx;
+  
+  /* Routine changes nothing unless a missing value is defined */
+  if(!has_mss_val) return;
+
+  /* Typecast pointer to values before access */
+  (void)cast_void_nctype(type,&op1);
+  if(has_mss_val) (void)cast_void_nctype(type,&mss_val);
+  
+  switch(type){
+  case NC_FLOAT:
+    {
+      const float mss_val_flt=*mss_val.fp;
+      for(idx=0;idx<sz;idx++) if(tally[idx] == 0L) op1.fp[idx]=mss_val_flt;
+    }
+    break;
+  case NC_DOUBLE:
+    {
+      const double mss_val_dbl=*mss_val.dp;
+      for(idx=0;idx<sz;idx++) if(tally[idx] == 0L) op1.dp[idx]=mss_val_dbl;
+    }
+    break;
+  case NC_INT:
+    {
+      const nco_int mss_val_ntg=*mss_val.ip;
+      for(idx=0;idx<sz;idx++) if(tally[idx] == 0L) op1.ip[idx]=mss_val_ntg;
+    }
+    break;
+  case NC_SHORT:
+    {
+      const nco_short mss_val_short=*mss_val.sp;
+      for(idx=0;idx<sz;idx++) if(tally[idx] == 0L) op1.sp[idx]=mss_val_short;
+    }
+    break;
+  case NC_USHORT:
+    {
+      const nco_ushort mss_val_ushort=*mss_val.usp;
+      for(idx=0;idx<sz;idx++) if(tally[idx] == 0L) op1.usp[idx]=mss_val_ushort;
+    }
+    break;
+  case NC_UINT:
+    {
+      const nco_uint mss_val_uint=*mss_val.uip;
+      for(idx=0;idx<sz;idx++) if(tally[idx] == 0L) op1.uip[idx]=mss_val_uint;
+    }
+    break;
+  case NC_INT64:
+    {
+      const nco_int64 mss_val_int64=*mss_val.i64p;
+      for(idx=0;idx<sz;idx++) if(tally[idx] == 0L) op1.i64p[idx]=mss_val_int64;
+    }
+    break;
+  case NC_UINT64:
+    {
+      const nco_uint64 mss_val_uint64=*mss_val.ui64p;
+      for(idx=0;idx<sz;idx++) if(tally[idx] == 0L) op1.ui64p[idx]=mss_val_uint64;
+    }
+    break;
+  case NC_BYTE: break; /* Do nothing */
+  case NC_UBYTE: break; /* Do nothing */
+  case NC_CHAR: break; /* Do nothing */
+  case NC_STRING: break; /* Do nothing */
+  default: nco_dfl_case_nc_type_err(); break;
+  } /* end switch */
+  
+  /* NB: it is not neccessary to un-typecast pointers to values after access 
+     because we have only operated on local copies of them. */
+  
+} /* end nco_var_tll_zro_mss_val() */
+
 void
 nco_var_nrm /* [fnc] Normalize value of first operand by count in tally array */
 (const nc_type type, /* I [enm] netCDF type of operand */
