@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_var_rth.h,v 1.31 2010/12/21 20:12:07 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_var_rth.h,v 1.34 2012/01/01 20:51:53 zender Exp $ */
 
 /* Purpose: Variable arithmetic */
 
-/* Copyright (C) 1995--2011 Charlie Zender
+/* Copyright (C) 1995--2012 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -68,6 +68,25 @@ extern "C" {
    ptr_unn op1, /* I [val] Values of first operand */
    ptr_unn op2); /* I/O [val] Values of second operand (running sum) on input, values of new sum on output */
   
+  void 
+  nco_var_copy_tll /* [fnc] Copy hyperslab variables of type var_typ from op1 to op2 */
+  (const nc_type type, /* I [enm] netCDF type */
+   const long sz, /* I [nbr] Number of elements to copy */
+   const int has_mss_val, /* I [flg] Flag for missing values */
+   ptr_unn mss_val, /* I [val] Value of missing value */
+   long * restrict const tally, /* O [nbr] Counter space */
+   const ptr_unn op1, /* I [sct] Values to copy */
+   ptr_unn op2); /* O [sct] Destination to copy values to */
+
+  void
+  nco_var_tll_zro_mss_val /* [fnc] Write missing value into elements with zero tally */
+  (const nc_type type, /* I [enm] netCDF type of operand */
+   const long sz, /* I [nbr] Size (in elements) of operand */
+   const int has_mss_val, /* I [flg] Flag for missing values */
+   ptr_unn mss_val, /* I [val] Value of missing value */
+   const long * const tally, /* I [nbr] Counter to normalize by */
+   ptr_unn op1); /* I/O [val] Values of first operand on input, possibly missing values on output */
+
   void
   nco_var_dvd /* [fnc] Divide second operand by first operand */
   (const nc_type type, /* I [type] netCDF type of operands */
