@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_var_utl.c,v 1.168 2011/03/04 23:35:29 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_var_utl.c,v 1.176 2012/01/01 20:51:53 zender Exp $ */
 
 /* Purpose: Variable utilities */
 
-/* Copyright (C) 1995--2011 Charlie Zender
+/* Copyright (C) 1995--2012 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -72,17 +72,17 @@ nco_cpy_var_dfn /* [fnc] Copy variable metadata from input to output file */
     
     /* Define dimension in output file if necessary */
     if(rcd_lcl != NC_NOERR){
-      if(!rec_dmn_nm || strcmp(dmn_nm,rec_dmn_nm))
+      if(!rec_dmn_nm || strcmp(dmn_nm,rec_dmn_nm)){
 	(void)nco_def_dim(out_id,dmn_nm,dmn_sz,dmn_out_id+idx);
-      else{
+      }else{
 	(void)nco_def_dim(out_id,dmn_nm,NC_UNLIMITED,dmn_out_id+idx);
         rec_dmn_out_id=dmn_out_id[idx];
       } /* end else */ 
 
     } /* end if */
 
-    /* Die if record dimension is not the first dimension */
-    if(idx>0 && dmn_out_id[idx]==rec_dmn_out_id ){
+    /* Die if record dimension is not first dimension */
+    if(idx>0 && dmn_out_id[idx]==rec_dmn_out_id){
       (void)fprintf(stdout,"%s: ERROR You defined the output record dimension to be \"%s\". Yet in the input variable \"%s\" the record dimension is dimension number %d. NCO (and the netCDF3 API) only supports the record dimension beging the first dimension. Consider using ncpdq to permute the location of the record dimension in the input file.\n",prg_nm_get(),rec_dmn_nm,var_nm,idx+1);  
       nco_exit(EXIT_FAILURE);
     } /* end if */
@@ -269,7 +269,7 @@ nco_cpy_var_val /* [fnc] Copy variable from input to output file, no limits */
   (void)nco_inq_var(out_id,var_out_id,(char *)NULL,&var_type,&nbr_dmn_out,(int *)NULL,(int *)NULL);
   (void)nco_inq_var(in_id,var_in_id,(char *)NULL,&var_type,&nbr_dmn_in,(int *)NULL,(int *)NULL);
   if(nbr_dmn_out != nbr_dmn_in){
-    (void)fprintf(stdout,"%s: ERROR attempt to write %d dimensional input variable %s to %d dimensional space in output file. \nHINT: When using -A (append) option, all appended variables must be the same rank in the input file as in the output file. The ncwa operator is useful at ridding variables of extraneous (size = 1) dimensions. See how at http://nco.sf.net/nco.html#ncwa\n",prg_nm_get(),nbr_dmn_in,var_nm,nbr_dmn_out);
+    (void)fprintf(stdout,"%s: ERROR attempt to write %d-dimensional input variable %s to %d-dimensional space in output file. \nHINT: When using -A (append) option, all appended variables must be the same rank in the input file as in the output file. The ncwa operator is useful at ridding variables of extraneous (size = 1) dimensions. See how at http://nco.sf.net/nco.html#ncwa\n",prg_nm_get(),nbr_dmn_in,var_nm,nbr_dmn_out);
     nco_exit(EXIT_FAILURE);
   } /* endif */
   nbr_dim=nbr_dmn_out;
@@ -285,9 +285,9 @@ nco_cpy_var_val /* [fnc] Copy variable from input to output file, no limits */
   
   /* Get dimension sizes from input file */
   for(idx=0;idx<nbr_dim;idx++){
-  /* nc_inq_dimlen() returns maximum value used so far in writing record dimension data
-     Until a record variable has been written, nc_inq_dimlen() returns dmn_sz=0 for record dimension in output file
-     Thus we read input file for dimension sizes */
+    /* nc_inq_dimlen() returns maximum value used so far in writing record dimension data
+       Until record variable has been written, nc_inq_dimlen() returns dmn_sz=0 for record dimension in output file
+       Thus we read input file for dimension sizes */
     (void)nco_inq_dimlen(in_id,dmn_id[idx],dmn_cnt+idx);
 
     /* Initialize indicial offset and stride arrays */
@@ -295,6 +295,32 @@ nco_cpy_var_val /* [fnc] Copy variable from input to output file, no limits */
     var_sz*=dmn_cnt[idx];
   } /* end loop over dim */
       
+  /* 20111130 TODO nco1029 warn on ncks -A when dim(old_record) != dim(new_record) */
+  if(nbr_dim > 0){
+    int rec_dmn_id=NCO_REC_DMN_UNDEFINED; /* [id] Record dimension ID in input file */
+    int rcd=NC_NOERR; /* [rcd] Return code */
+    long rec_dmn_sz=0L; /* [nbr] Record dimension size in output file */
+    rcd=nco_inq_unlimdim_flg(in_id,&rec_dmn_id); 
+    /* If input file has record dimension ... */
+    if(rcd == NC_NOERR){ 
+      /* ... used as record dimension of this variable...  */
+      if(rec_dmn_id == dmn_id[0]){
+	rcd=nco_inq_unlimdim(out_id,&rec_dmn_id); 
+	/* ... and if output file has record dimension ... */
+	if(rcd == NC_NOERR){ 
+	  (void)nco_inq_dimlen(out_id,rec_dmn_id,&rec_dmn_sz);
+	  /* ... and record dimension size in output file is non-zero (meaning at least one record has been written) ... */
+	  if(rec_dmn_sz > 0){
+	    /* ... then check input vs. output record dimension sizes ... */
+	    if(rec_dmn_sz != dmn_cnt[0]){
+	      (void)fprintf(stderr,"%s: WARNING record dimension size of %s changes between input and output files from %ld to %ld. Appended variable %s will likely be corrupt.\n",prg_nm_get(),var_nm,dmn_cnt[0],rec_dmn_sz,var_nm);
+	    } /* endif sizes are incommensurate */
+	  } /* endif records exist in output file */
+	} /* endif output file has record dimension */
+      } /* endif this variable uses input file record dimension */
+    } /* endif input file has record dimension */
+  } /* endif this variable is not a scalar */
+    
   /* Allocate enough space to hold variable */
   void_ptr=(void *)nco_malloc_dbg(var_sz*nco_typ_lng(var_type),"Unable to malloc() value buffer when copying hypserslab from input to output file",fnc_nm);
 
@@ -335,7 +361,9 @@ nco_cpy_var_val_lmt /* [fnc] Copy variable data from input to output file, simpl
   /* NB: nco_cpy_var_val_lmt() contains OpenMP critical region */
   /* Purpose: Copy variable data from input netCDF file to output netCDF file 
      Truncate dimensions in variable definition in output file according to user-specified limits
-     Copy variable-by-variable, old-style, used only by ncks */
+     Copy variable-by-variable, old-style, 
+     Routine was used by ncks until MSA implementation in ~2005 
+     Functionality now extended and superceded by nco_cpy_var_val_mlt_lmt() */
 
   nco_bool SRD=False;
   nco_bool WRP=False;
@@ -374,7 +402,7 @@ nco_cpy_var_val_lmt /* [fnc] Copy variable data from input to output file, simpl
   (void)nco_inq_var(out_id,var_out_id,(char *)NULL,&var_type,&nbr_dmn_out,(int *)NULL,(int *)NULL);
   (void)nco_inq_var(in_id,var_in_id,(char *)NULL,&var_type,&nbr_dmn_in,(int *)NULL,(int *)NULL);
   if(nbr_dmn_out != nbr_dmn_in){
-    (void)fprintf(stderr,"%s: ERROR attempt to write %d dimensional input variable %s to %d dimensional space in output file\n",prg_nm_get(),nbr_dmn_in,var_nm,nbr_dmn_out);
+    (void)fprintf(stderr,"%s: ERROR attempt to write %d-dimensional input variable %s to %d-dimensional space in output file\n",prg_nm_get(),nbr_dmn_in,var_nm,nbr_dmn_out);
     nco_exit(EXIT_FAILURE);
   } /* endif */
   nbr_dim=nbr_dmn_out;
@@ -880,16 +908,18 @@ var_dfl_set /* [fnc] Set defaults for each member of variable structure */
 } /* end var_dfl_set() */
 
 void 
-var_copy /* [fnc] Copy hyperslab variables of type var_typ from op1 to op2 */
+nco_var_copy /* [fnc] Copy hyperslab variables of type var_typ from op1 to op2 */
 (const nc_type var_typ, /* I [enm] netCDF type */
  const long sz, /* I [nbr] Number of elements to copy */
  const ptr_unn op1, /* I [sct] Values to copy */
  ptr_unn op2) /* O [sct] Destination to copy values to */
 {
   /* Purpose: Copy hyperslab variables of type var_typ from op1 to op2
-     Assumes memory area in op2 has already been malloc()'d */
+     Assumes memory area in op2 has already been malloc()'d
+     nco_var_copy(): Does nothing with missing values and tallies
+     nco_var_copy_tll(): Accounts for missing values in tally */
   (void)memcpy((void *)(op2.vp),(void *)(op1.vp),sz*nco_typ_lng(var_typ));
-} /* end var_copy() */
+} /* end nco_var_copy() */
 
 void
 nco_var_dfn /* [fnc] Define variables and write their attributes to output file */
@@ -907,11 +937,12 @@ nco_var_dfn /* [fnc] Define variables and write their attributes to output file
   /* Purpose: Define variables in output file, copy their attributes */
 
   /* This function is unusual (for me) in that dimension arguments are only intended
-     to be used by certain programs, those that alter the rank of input variables. 
+     to be used by certain programs---those that alter the rank of input variables. 
      Programs that do not alter input variable rank (dimensionality) should
      call this function with NULL dimension list and nbr_dmn_ncl=0. 
      Otherwise, this routine attempts to define variable correctly in output file 
-     (allowing variable to be defined with only those dimensions that are in dimension inclusion list) without altering variable structures. 
+     (allowing variable to be defined with only those dimensions that are in dimension inclusion list) 
+     without altering variable structures. 
 
      Moreover, this function is intended to be called with var_prc_out, not var_prc
      So local variable var usually refers to var_prc_out in calling function 
