@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_var_utl.h,v 1.61 2010/12/21 20:12:07 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_var_utl.h,v 1.63 2012/01/01 20:51:53 zender Exp $ */
 
 /* Purpose: Variable utilities */
 
-/* Copyright (C) 1995--2011 Charlie Zender
+/* Copyright (C) 1995--2012 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -79,7 +79,7 @@ extern "C" {
    const int lmt_nbr); /* I [nbr] Number of hyperslab limits */
  
   void 
-  var_copy /* [fnc] Copy hyperslab variables of type var_typ from op1 to op2 */
+  nco_var_copy /* [fnc] Copy hyperslab variables of type var_typ from op1 to op2 */
   (const nc_type var_typ, /* I [enm] netCDF type */
    const long sz, /* I [nbr] Number of elements to copy */
    const ptr_unn op1, /* I [sct] Values to copy */
