@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/ncra.c,v 1.266 2011/02/21 22:38:42 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/ncra.c,v 1.270 2012/01/01 20:51:53 zender Exp $ */
 
 /* This single source file may be called as three separate executables:
    ncra -- netCDF running averager
@@ -9,7 +9,7 @@
    specfied variables of multiple input netCDF files and output them 
    to a single file. */
 
-/* Copyright (C) 1995--2011 Charlie Zender
+/* Copyright (C) 1995--2012 Charlie Zender
 
    License: GNU General Public License (GPL) Version 3
    The full license text is at http://www.gnu.org/copyleft/gpl.html 
@@ -128,8 +128,8 @@ main(int argc,char **argv)
   
   char *sng_cnv_rcd=char_CEWI; /* [sng] strtol()/strtoul() return code */
 
-  const char * const CVS_Id="$Id: ncra.c,v 1.266 2011/02/21 22:38:42 zender Exp $"; 
-  const char * const CVS_Revision="$Revision: 1.266 $";
+  const char * const CVS_Id="$Id: ncra.c,v 1.270 2012/01/01 20:51:53 zender Exp $"; 
+  const char * const CVS_Revision="$Revision: 1.270 $";
   const char * const opt_sht_lst="346ACcD:d:FHhL:l:n:Oo:p:P:rRt:v:X:xY:y:-:";
 
   cnk_sct **cnk=NULL_CEWI;
@@ -555,28 +555,23 @@ main(int argc,char **argv)
     lmt_rec=nco_lmt_sct_mk(in_id,rec_dmn_id,lmt,lmt_nbr,FORTRAN_IDX_CNV);
     /* Initialize record coordinate re-basing */
     if(prg == ncra || prg == ncrcat){
-      lmt_rec->origin=0.0; 
       int var_id;
-      char *cln_att_sng=(char*)NULL;
-
-      lmt_rec->rbs_sng=(char *)NULL;
+      
       lmt_rec->lmt_cln=cln_nil; 
+      lmt_rec->origin=0.0; 
+      lmt_rec->rbs_sng=NULL;
 
-
+      /* Obtain metadata for record coordinate */
       rcd=nco_inq_varid_flg(in_id,lmt_rec->nm,&var_id);
-
-
       if(rcd == NC_NOERR){ 
-       lmt_rec->rbs_sng=nco_lmt_get_udu_att(in_id,var_id,"units"); 
-       cln_att_sng=nco_lmt_get_udu_att(in_id,var_id,"calendar"); 
-       lmt_rec->lmt_cln=nco_cln_get_cln_typ(cln_att_sng); 
-      }
-
-      if(cln_att_sng)
-        cln_att_sng=(char*)nco_free(cln_att_sng);  
-
+	char *cln_att_sng=NULL;
+	lmt_rec->rbs_sng=nco_lmt_get_udu_att(in_id,var_id,"units"); 
+	cln_att_sng=nco_lmt_get_udu_att(in_id,var_id,"calendar"); 
+	lmt_rec->lmt_cln=nco_cln_get_cln_typ(cln_att_sng); 
+	if(cln_att_sng) cln_att_sng=(char*)nco_free(cln_att_sng);  
+      } /* endif record coordinate exists */
     } /* endif ncra, ncrcat */
-  } /* Record dimension exists */
+  } /* endif record dimension exists */
   
   if(rec_dmn_id != NCO_REC_DMN_UNDEFINED){
     for(idx=0;idx<nbr_dmn_fl;idx++){
@@ -675,7 +670,6 @@ main(int argc,char **argv)
       /* Allocate space for only one record */
       /*var_prc_out[idx]->sz=var_prc[idx]->sz=var_prc[idx]->sz_rec;*/
       var_prc[idx]->sz=var_prc[idx]->sz_rec=var_prc_out[idx]->sz=var_prc_out[idx]->sz_rec;
-
     } /* endif */
     if(prg == ncra || prg == ncea){
       var_prc_out[idx]->tally=var_prc[idx]->tally=(long *)nco_malloc(var_prc_out[idx]->sz*sizeof(long));
@@ -685,7 +679,6 @@ main(int argc,char **argv)
     } /* end if */
   } /* end loop over idx */
 
-
   /* Timestamp end of metadata setup and disk layout */
   rcd+=nco_ddra((char *)NULL,(char *)NULL,&ddra_info);
   ddra_info.tmr_flg=nco_tmr_rgl;
@@ -772,7 +765,7 @@ main(int argc,char **argv)
 		   Output variable type is "sticky" so only convert on first record */
 	        if(idx_rec_out == 0L) var_prc_out[idx]=nco_typ_cnv_rth(var_prc_out[idx],nco_op_typ);
 	        var_prc[idx]=nco_var_cnf_typ(var_prc_out[idx]->type,var_prc[idx]);
-	      /* Perform arithmetic operations: avg, min, max, ttl, ... */
+		/* Perform arithmetic operations: avg, min, max, ttl, ... */
 	        nco_opr_drv(idx_rec_out,nco_op_typ,var_prc[idx],var_prc_out[idx]);
               } /* end else */ 
 	    } /* end if ncra */
@@ -883,6 +876,7 @@ main(int argc,char **argv)
 	case nco_op_min: /* Minimum is already in buffer, do nothing */
 	case nco_op_max: /* Maximum is already in buffer, do nothing */
 	case nco_op_ttl: /* Total is already in buffer, do nothing */
+	  break;
 	default:
 	  break;
 	} /* end switch */
